@@ -23,7 +23,7 @@ require Exporter;
 
 @EXPORT = qw();
 
-$VERSION = '1.05';
+$VERSION = '1.07';
 
 # Preloaded methods go here.
 # -----------------------------------------------------------------
@@ -314,6 +314,7 @@ sub getXMLFileName
 sub new
 {
 	my($class, $optionRef)		= @_;
+	$class						= ref($class) || $class;
 	my($self)					= (ref($optionRef) eq 'HASH') ? $optionRef : {};
 	$self -> {'debug'}			= '' if (! defined($self -> {'debug'}) );
 	$self -> {'form2file'}		= '' if (! defined($self -> {'form2file'}) );
@@ -786,7 +787,7 @@ __END__
 
 =head1 NAME
 
-CGI::Formalware.pm - Convert an XML file into a suite of CGI forms.
+C<CGI::Formalware> - Convert an XML file into a suite of CGI forms.
 
 =head1 SYNOPSIS
 
@@ -804,7 +805,7 @@ where x.pl contains nothing more than:
 	$form -> process();
 	exit(0);
 
-Upon starting, CGI::Formalware.pm asks for the name of your XML file, which
+Upon starting, C<CGI::Formalware> asks for the name of your XML file, which
 is assumed to be in cgi-bin/.
 
 =head1 DESCRIPTION
@@ -813,13 +814,39 @@ To provide a type of repository for frequently used scripts, which can then be e
 locally or remotely (via Net::Telnet), by just entering a password (for remote scripts),
 and clicking.
 
+=head1 INSTALLATION
+
+You install C<CGI::Formalware>, as you would install any perl module library,
+by running these commands:
+
+	perl Makefile.PL
+	make
+	make test
+	make install
+
+If you want to install a private copy of C<CGI::Formalware> in your home
+directory, then you should try to produce the initial Makefile with
+something like this command:
+
+	perl Makefile.PL LIB=~/perl
+		or
+	perl Makefile.PL LIB=C:/Perl/Site/Lib
+
+If, like me, you don't have permission to write man pages into unix system
+directories, use:
+
+	make pure_install
+
+instead of make install. This option is secreted in the middle of p 414 of the
+second edition of the dromedary book.
+
 =head1 AUDIENCE
 
 Webmasters.
 
 =head1 SECURITY
 
-None. Even worse, CGI::Formalware.pm is designed to circumvent a web server's
+None. Even worse, C<CGI::Formalware> is designed to circumvent a web server's
 concept of what Apache calls DocumentRoot.
 
 =head1 CONSTRUCTOR new
@@ -894,7 +921,7 @@ field whose name appears between the % signs
 
 =item *
 
-A script whose last line is 'ftp -n -v' is recognized and handled specially.
+A script whose last line is 'ftp B<-n> B<-v>' is recognized and handled specially.
 Your form must contain textFields called 'host', 'username' and 'password' and
 'fileName'. A binary 'get' is performed. This will be made more flexible one day
 
@@ -1161,15 +1188,20 @@ CGI
 
 Net::Telnet
 
-=item 4
+=item *
 
 XML::DOM
 
 =back
 
+=head1 TO DO
+
+DOS directory text '... <DIR>' is changed to '... {DIR}', so that it
+does not look like HTML. This needs to be handled more cleanly.
+
 =head1 AUTHOR
 
-C<CGI::Formalware.pm> was written by Ron Savage I<E<lt>rpsavage@ozemail.com.auE<gt>>
+C<CGI::Formalware> was written by Ron Savage I<E<lt>rpsavage@ozemail.com.auE<gt>>
 in 1999.
 
 Copyright (c) 1999 Ron Savage.
